Instrument — MSUMastro toolbox 0.1 documentation

# Instrument

class `msumastro.header_processing.feder.` `Instrument`(name, fits_names=None, rows=0, columns=0, overscan_start=None, overscan_axis=None)

  Bases: `object`

  Telescope instrument with simple properties.

  Parameters: | name : str Name of the instrument. fits_names : list of str List of names by which the instrument is known in FITS headers rows : int Number of rows in an image produced by this instrument, including overscan. columns : int Number of columns in an image produced by this instrument, including overscan. overscan_start : int Position at which the overscan starts. The overscan region is assumed to extend from this starting position to the edge of the image. overscan_axis : one of (1, 2) Axis along which the overscan varies. Numbers correspond to `NAXIS1` and `NAXIS2` in the FITS header.

  Examples

  Consider an image whose dimensions as given in its FITS header are `NAXIS1 = 3085` and `NAXIS2 = 2048` with an overscan region that begins at position 3073 along axis 1. The correct overscan settings for this instrument are:

      overscan_start = 3073
      overscan_axis = 1

  Methods Summary

  `has_overscan`(image_dimensions) | Determine whether an image taken by this instrument has overscan :Parameters: image_dimensions : list-like with two elements Shape of the image; can be any type as long as it has two elements.

  Methods Documentation

  `has_overscan`(image_dimensions)

    Determine whether an image taken by this instrument has overscan

    Parameters: | image_dimensions : list-like with two elements Shape of the image; can be any type as long as it has two elements.
    Returns: | bool Indicates whether or not image has overscan present.